@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Position of notes in a scale
 
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 use Carp;
 use Moo;
@@ -80,7 +80,7 @@ Music::ScaleNote - Position of notes in a scale
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ Default: C
 
 =head2 scale_name
 
-L<Music::Scales/SCALES>
+See L<Music::Scales/SCALES> for the possible names.
 
 Default: major
 
@@ -127,7 +127,7 @@ Create a new C<Music::ScaleNote> object.
   $note = $msn->get_offset(%arguments);
 
 Return a new L<Music::Note> object based on the given B<note_name>,
-B<note_format> and L<offset>.
+B<note_format> and B<offset>.
 
 =head1 SEE ALSO
 
